#
# spec file for package python-w3lib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-w3lib
Version:        2.2.1
Release:        2.4
Summary:        Library of Web-Related Functions
License:        BSD-3-Clause
URL:            https://github.com/scrapy/w3lib
Source:         https://files.pythonhosted.org/packages/source/w/w3lib/w3lib-%{version}.tar.gz
# PATCH-FIX-OPENSUSE Do not check invalid IPv6 addresses
Patch0:         do-not-add-invalid-ipv6.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This is a Python library of web-related functions, such as:

* remove comments, or tags from HTML snippets

* extract base url from HTML snippets

* translate entites on HTML strings

* encoding mulitpart/form-data

* convert raw HTTP headers to dicts and vice-versa

* construct HTTP auth header

* converting HTML pages to unicode

* RFC-compliant url joining

* sanitize urls (like browsers do)

* extract arguments from urls

%prep
%autosetup -p1 -n w3lib-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/w3lib
%{python_sitelib}/w3lib-%{version}.dist-info

%changelog
* Tue Nov 26 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch do-not-add-invalid-ipv6.patch:
  * Do not check invalid IPv6 addresses.
* Thu Jun 13 2024 Dirk Müller <dmueller@suse.com>
- update to 2.2.1:
  * :func:`~w3lib.url.canonicalize_url` no longer applies
    lowercase to the userinfo URL component. (#229, #230)
* Mon Jun 10 2024 Dirk Müller <dmueller@suse.com>
- update to 2.2.0:
  * Dropped Python 3.7 support (#214).
  * Added Python 3.12 and PyPy 3.10 support (#218).
  * Added the description to the package metadata (#227).
  * Improved type hints (#226).
  * Added the ``pre-commit`` configuration, code reformatted with
    ``black``
  * Updated CI configuration (#217, #227).
- use PEP517 build
* Fri Jan 12 2024 Dirk Müller <dmueller@suse.com>
- update to 2.1.2:
  * Fix test failures on Python 3.11.4+ (#212, #213).
  * Fix an incorrect type hint (#211).
  * Add project URLs to setup.py (#215).
  * Dropped Python 3.6 support, and made Python 3.11 support
    official.
  * :func:`~w3lib.url.safe_url_string` now generates safer
    URLs.
  * :func:`~w3lib.url.canonicalize_url` now strips spaces from
    the input URL, to be more in line with the `URL living standard`_.
  * :func:`~w3lib.html.get_base_url` now ignores HTML comments.
  * Fixed :func:`~w3lib.url.safe_url_string` re-encoding
    percent signs on the URL username and password even when
    they were being used as part of an escape sequence. (#187, #196)
  * Fixed :func:`~w3lib.http.basic_auth_header` using the wrong
    flavor of base64 encoding, which could prevent authentication
    in rare cases.
  * Python 2 is no longer supported;
  * The ``w3lib.form`` module is removed.
  * The ``w3lib.html.remove_entities`` function is removed.
  * The ``w3lib.url.urljoin_rfc`` function is removed.
  * The following functions are deprecated, and will be removed
    in future releases
  * Type annotations are added (#172, #184).
  * Added support for Python 3.9 and 3.10 (#168, #176).
  * Fixed :func:`w3lib.html.get_meta_refresh` for ``<meta>`` tags
    where ``http-equiv`` is written after ``content`` (#179).
  * Fixed :func:`w3lib.url.safe_url_string` for IDNA domains with
    ports (#174).
  * :func:`w3lib.url.url_query_cleaner` no longer adds an
    unneeded ``#`` when ``keep_fragments=True`` is passed, and
    the URL doesn't have a fragment
  * Removed a workaround for an ancient pathname2url bug (#142)
  * CI is migrated to GitHub Actions (#166, #177); other CI
    improvements
  * The code is formatted using black (#173).
- drop 166-add-xfail-test_add_or_replace_parameter_fail.patch,
  python-w3lib-no-six.patch: upstream
* Fri Oct 14 2022 pgajdos@suse.com
- do not require six
- added patches
  https://github.com/scrapy/w3lib/commit/c16d7bac3af3148b7018c67ef7922a5da6b3e640
  + python-w3lib-no-six.patch
* Fri Mar 19 2021 Matej Cepl <mcepl@suse.com>
- Add 166-add-xfail-test_add_or_replace_parameter_fail.patch,
  which makes tests working with CVE-2021-23336 (bsc#1181270).
* Wed Jul 22 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.22.0
  * Python 3.4 is no longer supported (issue #156)
  * :func:`w3lib.url.safe_url_string` now supports an optional ``quote_path``
    parameter to disable the percent-encoding of the URL path
  * more small fixes and improvements
* Thu Aug 29 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.21.0
  * Add the "encoding" and "path_encoding" parameters to
    w3lib.url.safe_download_url (issue #118)
  * w3lib.url.safe_url_string now also removes tabs and new lines
    (issue #133)
  * w3lib.html.remove_comments now also removes truncated comments
    (issue #129)
  * w3lib.html.remove_tags_with_content no longer removes tags which
    start with the same text as one of the specified tags (issue #114)
* Fri Mar 29 2019 pgajdos@suse.com
- version update to 1.20.0
  * Fix url_query_cleaner to do not append "?" to urls without a
    query string (issue #109)
  * Add support for Python 3.7 and drop Python 3.3 (issue #113)
  * Add `w3lib.url.add_or_replace_parameters` helper (issue #117)
  * Documentation fixes (issue #115)
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Nov 16 2018 Todd R <toddrme2178@gmail.com>
- Update to version 1.19.0
  * Add a workaround for CPython segfault (https://bugs.python.org/issue32583)
    which affect w3lib.encoding functions. This is technically **backwards
    incompatible** because it changes the way non-decodable bytes are replaced
    (in some cases instead of two ``\ufffd`` chars you can get one).
    As a side effect, the fix speeds up decoding in Python 3.4+.
  * Add 'encoding' parameter for w3lib.http.basic_auth_header.
  * Fix pypy testing setup, add pypy3 to CI.
* Thu Dec 21 2017 mpluskal@suse.com
- Update to version 1.18.0:
  * No upstream changelog available
- Convert to singlespec
* Thu Jun  2 2016 jacobwinski@gmail.com
- Update to 1.14.2 (2016-04-11)
  * fix function import for (deprecated) ``urljoin_rfc`` (issue #51)
  * only expose wanted functions from ``w3lib.url``, via ``__all__``
    (see issue #54, https://github.com/scrapy/scrapy/issues/1917)
- Update to 1.14.1 (2016-04-07)
  * For bytes URLs, when supplied encoding (or default UTF8) is wrong,
    ``safe_url_string`` falls back to percent-encoding offending bytes.
- Update to 1.14.0 (2016-04-06)
  * proper handling of non-ASCII characters in Python2 and Python3
  * support IDNs
  * new `path_encoding` to override default UTF-8 when serializing non-ASCII
    characters before percent-encoding
  * html_body_declared_encoding also detects encoding when not sole attribute
    in ``<meta>``.
  * Package is now properly marked as ``zip_safe``.
- Update to 1.13.0 (2015-11-05)
  * remove_tags removes uppercase tags as well;
  * ignore meta-redirects inside script or noscript tags by default,
    but add an option to not ignore them;
  * replace_entities now handles entities without trailing semicolon;
  * fixed uncaught UnicodeDecodeError when decoding entities.
- Update to 1.12.0 (2015-06-29)
  * meta_refresh regex now handles leading newlines and whitespaces in the url;
  * include tests folder in source distribution.
- Update to 1.11.0 (2015-01-13)
  * url_query_cleaner now supports str or list parameters;
  * add support for resolving base URLs in <base> tags with attributes
    before href.
- Update spec file to reflect new upstream package requirements.
* Fri Sep  5 2014 toddrme2178@gmail.com
- Update to version 1.10.0
  + See https://github.com/scrapy/w3lib/commits/v1.10.0 for a list
    of changes.
* Fri Nov 15 2013 p.drouand@gmail.com
- Update to version 1.5
  + No changelog available
- Add python-setuptools BuildRequires; new dependency
* Wed May 23 2012 jfunk@funktronics.ca
- Initial release
